import { config } from "dotenv";
config();

import "./fetch-polyfill.js";

import express from "express";
import { connectDatabase } from "./db.js";
import { saveResult } from "./monitoring.js";
import { filter } from "./pipeline/filters.js";
import { resolveInformation } from "./pipeline/resolveInformation.js";
import { ValidationInput } from "./types.js";

const app = express();
const port = 10720;

app.get("/", (_, res) => {
  res.send({
    shield: "1.0.0",
  });
});

app.use(express.json());

async function runPipeline(input: ValidationInput) {
  const info = await resolveInformation(input);
  const result = await filter(input, info);

  saveResult({
    timestamp: new Date().toISOString(),
    ...result,
    input,
    info,
  });

  return result;
}

app.post("/validate", async (req, res) => {
  if (
    req.headers["authorization"] !==
    // -SNIP PUBLIC RELEASE-
  )
    return res.send("f");

  console.info("Incoming request for", req.body.email);
  res.send(await runPipeline(req.body as ValidationInput));
});

connectDatabase().then(() => {
  app.listen(port, () => {
    console.log(`Authifier Shield listening on port ${port}`);
  });
});
