import {
  BlockReason,
  ResolvedInformation,
  ValidationInput,
  ValidationResult,
} from "../types.js";

/**
 * Filters currently in-use
 */
const FILTERS: Record<
  BlockReason,
  (
    input: ValidationInput,
    info: ResolvedInformation
  ) => boolean | Promise<boolean>
> = {
  // -SNIP PUBLIC RELEASE-
};

/**
 * Run the filter pipeline on the given information
 * @param input Input data
 * @param info Resolved information
 * @returns Output information
 */
export async function filter(
  input: ValidationInput,
  info: ResolvedInformation
): Promise<ValidationResult> {
  const reasons = [];
  for (const filter of Object.keys(FILTERS) as BlockReason[]) {
    if (await FILTERS[filter](input, info)) {
      reasons.push(filter);
    }
  }

  return {
    blocked: reasons.length > 0,
    reasons,
  };
}
